@@ -348,13 +348,12 @@ class APIBatchRowView(APIBatchMixin, APIMasterView):
         route_prefix = cls.get_route_prefix()
         permission_prefix = cls.get_permission_prefix()
         collection_url_prefix = cls.get_collection_url_prefix()
-        object_url_prefix = cls.get_object_url_prefix()
 
         if cls.supports_quick_entry:
 
             # quick entry
-            config.add_route('{}.quick_entry'.format(route_prefix), '{}/quick-entry'.format(collection_url_prefix),
-                             request_method=('OPTIONS', 'POST'))
-            config.add_view(cls, attr='quick_entry', route_name='{}.quick_entry'.format(route_prefix),
-                            permission='{}.edit'.format(permission_prefix),
-                            renderer='json')
+            quick_entry = Service(name='{}.quick_entry'.format(route_prefix),
+                                  path='{}/quick-entry'.format(collection_url_prefix))
+            quick_entry.add_view('POST', 'quick_entry', klass=cls,
+                                 permission='{}.edit'.format(permission_prefix))
+            config.add_cornice_service(quick_entry)
