@@ -29,6 +29,8 @@ API.
 
 from __future__ import unicode_literals, absolute_import
 
+import datetime
+
 import six
 
 from rattail.db import model
@@ -94,6 +96,8 @@ class OrderingBatchViews(APIBatchView):
         if batch.executed:
             raise self.forbidden()
 
+        app = self.get_rattail_app()
+
         # TODO: much of the logic below was copied from the traditional master
         # view for ordering batches.  should maybe let them share it somehow?
 
@@ -104,10 +108,10 @@ class OrderingBatchViews(APIBatchView):
 
         # organize vendor catalog costs by dept / subdept
         departments = {}
-        costs = self.handler.get_order_form_costs(self.Session(), batch.vendor)
-        costs = self.handler.sort_order_form_costs(costs)
+        costs = self.batch_handler.get_order_form_costs(self.Session(), batch.vendor)
+        costs = self.batch_handler.sort_order_form_costs(costs)
         costs = list(costs)   # we must have a stable list for the rest of this
-        self.handler.decorate_order_form_costs(batch, costs)
+        self.batch_handler.decorate_order_form_costs(batch, costs)
         for cost in costs:
 
             department = cost.product.department
@@ -175,10 +179,20 @@ class OrderingBatchViews(APIBatchView):
             sorted_departments.append(dept)
 
         # fetch recent purchase history, sort/pad for template convenience
-        history = self.handler.get_order_form_history(batch, costs, 6)
+        history = self.batch_handler.get_order_form_history(batch, costs, 6)
         for i in range(6 - len(history)):
             history.append(None)
         history = list(reversed(history))
+        # must convert some date objects to string, for JSON sake
+        for h in history:
+            purchase = h.get('purchase')
+            if purchase:
+                dt = purchase.get('date_ordered')
+                if dt and isinstance(dt, datetime.date):
+                    purchase['date_ordered'] = app.render_date(dt)
+                dt = purchase.get('date_received')
+                if dt and isinstance(dt, datetime.date):
+                    purchase['date_received'] = app.render_date(dt)
 
         return {
             'batch': self.normalize(batch),
@@ -266,10 +280,10 @@ class OrderingBatchRowViews(APIBatchRowView):
 
         Note that the "normal" logic for this method is not invoked at all.
         """
-        if not self.handler.is_mutable(row.batch):
+        if not self.batch_handler.is_mutable(row.batch):
             return {'error': "Batch is not mutable"}
 
-        self.handler.update_row_quantity(row, **data)
+        self.batch_handler.update_row_quantity(row, **data)
         return row
 
 
