@@ -31,6 +31,7 @@ import humanize
 from rattail.db import model
 from rattail.util import pretty_quantity
 
+from cornice import Service
 from deform import widget as dfwidget
 
 from tailbone import forms
@@ -143,26 +144,26 @@ class ReceivingBatchViews(APIBatchView):
         collection_url_prefix = cls.get_collection_url_prefix()
         object_url_prefix = cls.get_object_url_prefix()
 
-        # auto-receive
-        config.add_route('{}.auto_receive'.format(route_prefix),
-                         '{}/{{uuid}}/auto-receive'.format(object_url_prefix))
-        config.add_view(cls, attr='auto_receive',
-                        route_name='{}.auto_receive'.format(route_prefix),
-                        permission='{}.auto_receive'.format(permission_prefix),
-                        renderer='json')
+        # auto_receive
+        auto_receive = Service(name='{}.auto_receive'.format(route_prefix),
+                               path='{}/{{uuid}}/auto-receive'.format(object_url_prefix))
+        auto_receive.add_view('GET', 'auto_receive', klass=cls,
+                              permission='{}.auto_receive'.format(permission_prefix))
+        config.add_cornice_service(auto_receive)
 
-        # mark receiving complete
-        config.add_route('{}.mark_receiving_complete'.format(route_prefix), '{}/{{uuid}}/mark-receiving-complete'.format(object_url_prefix))
-        config.add_view(cls, attr='mark_receiving_complete', route_name='{}.mark_receiving_complete'.format(route_prefix),
-                        permission='{}.edit'.format(permission_prefix),
-                        renderer='json')
+        # mark_receiving_complete
+        mark_receiving_complete = Service(name='{}.mark_receiving_complete'.format(route_prefix),
+                                          path='{}/{{uuid}}/mark-receiving-complete'.format(object_url_prefix))
+        mark_receiving_complete.add_view('POST', 'mark_receiving_complete', klass=cls,
+                                         permission='{}.edit'.format(permission_prefix))
+        config.add_cornice_service(mark_receiving_complete)
 
         # eligible purchases
-        config.add_route('{}.eligible_purchases'.format(route_prefix), '{}/eligible-purchases'.format(collection_url_prefix),
-                         request_method='GET')
-        config.add_view(cls, attr='eligible_purchases', route_name='{}.eligible_purchases'.format(route_prefix),
-                        permission='{}.create'.format(permission_prefix),
-                        renderer='json')
+        eligible_purchases = Service(name='{}.eligible_purchases'.format(route_prefix),
+                                     path='{}/eligible-purchases'.format(collection_url_prefix))
+        eligible_purchases.add_view('GET', 'eligible_purchases', klass=cls,
+                                    permission='{}.create'.format(permission_prefix))
+        config.add_cornice_service(eligible_purchases)
 
 
 class ReceivingBatchRowViews(APIBatchRowView):
@@ -437,11 +438,11 @@ class ReceivingBatchRowViews(APIBatchRowView):
         object_url_prefix = cls.get_object_url_prefix()
 
         # receive (row)
-        config.add_route('{}.receive'.format(route_prefix), '{}/{{uuid}}/receive'.format(object_url_prefix),
-                         request_method=('OPTIONS', 'POST'))
-        config.add_view(cls, attr='receive', route_name='{}.receive'.format(route_prefix),
-                        permission='{}.edit_row'.format(permission_prefix),
-                        renderer='json')
+        receive = Service(name='{}.receive'.format(route_prefix),
+                          path='{}/{{uuid}}/receive'.format(object_url_prefix))
+        receive.add_view('POST', 'receive', klass=cls,
+                         permission='{}.edit_row'.format(permission_prefix))
+        config.add_cornice_service(receive)
 
 
 def defaults(config, **kwargs):
