@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Authentication & Authorization
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import logging
 
 from rattail import enum
@@ -107,7 +105,7 @@ class TailboneAuthorizationPolicy(object):
                     # re-creating the database, which means new user uuids.
                     # TODO: the odds of this query returning a user in that
                     # case, are probably nil, and we should just skip this bit?
-                    user = Session.query(model.User).get(userid)
+                    user = Session.get(model.User, userid)
                     if user:
                         if auth.has_permission(Session(), user, permission):
                             return True
