@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,13 +24,10 @@
 Grid Filters
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import re
 import datetime
 import logging
 
-import six
 import sqlalchemy as sa
 
 from rattail.gpc import GPC
@@ -117,7 +114,7 @@ class EnumValueRenderer(ChoiceValueRenderer):
             sorted_keys = list(enum.keys())
         else:
             sorted_keys = sorted(enum, key=lambda k: enum[k].lower())
-        self.options = [tags.Option(enum[k], six.text_type(k)) for k in sorted_keys]
+        self.options = [tags.Option(enum[k], str(k)) for k in sorted_keys]
 
 
 class GridFilter(object):
@@ -173,10 +170,12 @@ class GridFilter(object):
     data_type = 'string'        # default, but will be set from value renderer
     choices = {}
 
-    def __init__(self, key, label=None, verbs=None, value_enum=None, value_renderer=None,
+    def __init__(self, key, config=None, label=None, verbs=None,
+                 value_enum=None, value_renderer=None,
                  default_active=False, default_verb=None, default_value=None,
                  encode_values=False, value_encoding='utf-8', **kwargs):
         self.key = key
+        self.config = config
         self.label = label or prettify(key)
         self.verbs = verbs or self.get_default_verbs()
         if value_renderer:
@@ -279,7 +278,7 @@ class GridFilter(object):
         return value if value is not UNSPECIFIED else self.value
 
     def encode_value(self, value):
-        if self.encode_values and isinstance(value, six.string_types):
+        if self.encode_values and isinstance(value, str):
             return value.encode('utf-8')
         return value
 
@@ -332,6 +331,38 @@ class AlchemyGridFilter(GridFilter):
             self.column != self.encode_value(value),
         ))
 
+    def filter_equal_any_of(self, query, value):
+        """
+        This filter expects "multiple values" separated by newline
+        character, and will add an "OR" condition with each value
+        being checked separately.  For instance if the user submits a
+        "value" like this:
+
+        .. code-block:: none
+
+           foo bar
+           baz
+
+        This will result in SQL condition like this:
+
+        .. code-block:: sql
+
+           name = 'foo bar' OR name = 'baz'
+        """
+        if not value:
+            return query
+
+        values = value.split('\n')
+        values = [value for value in values if value]
+        if not values:
+            return query
+
+        conditions = []
+        for value in values:
+            conditions.append(self.column == self.encode_value(value))
+
+        return query.filter(sa.or_(*conditions))
+
     def filter_is_null(self, query, value):
         """
         Filter data with an 'IS NULL' query.  Note that this filter does not
@@ -431,7 +462,7 @@ class AlchemyStringFilter(AlchemyGridFilter):
         """
         return ['contains', 'does_not_contain',
                 'contains_any_of',
-                'equal', 'not_equal',
+                'equal', 'not_equal', 'equal_any_of',
                 'is_empty', 'is_not_empty',
                 'is_null', 'is_not_null',
                 'is_empty_or_null',
@@ -536,7 +567,7 @@ class AlchemyByteStringFilter(AlchemyStringFilter):
 
     def get_value(self, value=UNSPECIFIED):
         value = super(AlchemyByteStringFilter, self).get_value(value)
-        if isinstance(value, six.text_type):
+        if isinstance(value, str):
             value = value.encode(self.value_encoding)
         return value
 
@@ -590,7 +621,7 @@ class AlchemyNumericFilter(AlchemyGridFilter):
         except ValueError:
             return True
 
-        return bool(value and len(six.text_type(value)) > 8)
+        return bool(value and len(str(value)) > 8)
 
     def filter_equal(self, query, value):
         if self.value_invalid(value):
