@@ -464,6 +464,12 @@ class MenuHandler(GenericHandler):
                     'route': 'vendorcatalogs',
                     'perm': 'vendorcatalogs.list',
                 },
+                {'type': 'sep'},
+                {
+                    'title': "Sample Files",
+                    'route': 'vendorsamplefiles',
+                    'perm': 'vendorsamplefiles.list',
+                },
             ],
         }
 
