@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,9 +24,6 @@
 Customer Views
 """
 
-from __future__ import unicode_literals, absolute_import
-
-import six
 import sqlalchemy as sa
 
 import colander
@@ -190,12 +187,12 @@ class CustomerView(MasterView):
             return instance
 
         # search by CustomerPerson.uuid
-        instance = self.Session.query(model.CustomerPerson).get(key)
+        instance = self.Session.get(model.CustomerPerson, key)
         if instance:
             return instance.customer
 
         # search by CustomerGroupAssignment.uuid
-        instance = self.Session.query(model.CustomerGroupAssignment).get(key)
+        instance = self.Session.get(model.CustomerGroupAssignment, key)
         if instance:
             return instance.customer
 
@@ -205,7 +202,6 @@ class CustomerView(MasterView):
         super(CustomerView, self).configure_common_form(f)
         customer = f.model_instance
         permission_prefix = self.get_permission_prefix()
-        use_buefy = self.get_use_buefy()
 
         f.set_renderer('default_email', self.render_default_email)
         if not self.creating and customer.emails:
@@ -251,12 +247,7 @@ class CustomerView(MasterView):
 
         # people
         if self.viewing:
-            if use_buefy:
-                f.set_renderer('people', self.render_people_buefy)
-            elif self.people_detachable and self.has_perm('detach_person'):
-                f.set_renderer('people', self.render_people_removable)
-            else:
-                f.set_renderer('people', self.render_people)
+            f.set_renderer('people', self.render_people_buefy)
         else:
             f.remove('people')
 
@@ -288,30 +279,28 @@ class CustomerView(MasterView):
 
         kwargs['show_profiles_helper'] = self.show_profiles_helper
 
-        use_buefy = self.get_use_buefy()
-        if use_buefy:
-            customer = kwargs['instance']
-            people = []
-            for person in customer.people:
-                data = {
-                    'uuid': person.uuid,
-                    'full_name': person.display_name,
-                    'first_name': person.first_name,
-                    'last_name': person.last_name,
-                    '_action_url_view': self.request.route_url('people.view',
-                                                               uuid=person.uuid),
-                }
-                if self.editable and self.request.has_perm('people.edit'):
-                    data['_action_url_edit'] = self.request.route_url(
-                        'people.edit',
-                        uuid=person.uuid)
-                if self.people_detachable and self.has_perm('detach_person'):
-                    data['_action_url_detach'] = self.request.route_url(
-                        'customers.detach_person',
-                        uuid=customer.uuid,
-                        person_uuid=person.uuid)
-                people.append(data)
-            kwargs['people_data'] = people
+        customer = kwargs['instance']
+        people = []
+        for person in customer.people:
+            data = {
+                'uuid': person.uuid,
+                'full_name': person.display_name,
+                'first_name': person.first_name,
+                'last_name': person.last_name,
+                '_action_url_view': self.request.route_url('people.view',
+                                                           uuid=person.uuid),
+            }
+            if self.editable and self.request.has_perm('people.edit'):
+                data['_action_url_edit'] = self.request.route_url(
+                    'people.edit',
+                    uuid=person.uuid)
+            if self.people_detachable and self.has_perm('detach_person'):
+                data['_action_url_detach'] = self.request.route_url(
+                    'customers.detach_person',
+                    uuid=customer.uuid,
+                    person_uuid=person.uuid)
+            people.append(data)
+        kwargs['people_data'] = people
 
         return kwargs
 
@@ -326,20 +315,20 @@ class CustomerView(MasterView):
 
     def render_default_address(self, customer, field):
         if customer.addresses:
-            return six.text_type(customer.addresses[0])
+            return str(customer.addresses[0])
 
     def grid_render_person(self, customer, field):
         person = getattr(customer, field)
         if not person:
             return ""
-        return six.text_type(person)
+        return str(person)
 
     def form_render_person(self, customer, field):
         person = getattr(customer, field)
         if not person:
             return ""
 
-        text = six.text_type(person)
+        text = str(person)
         url = self.request.route_url('people.view', uuid=person.uuid)
         return tags.link_to(text, url)
 
@@ -350,12 +339,13 @@ class CustomerView(MasterView):
 
         items = []
         for person in people:
-            text = six.text_type(person)
+            text = str(person)
             url = self.request.route_url('people.view', uuid=person.uuid)
             link = tags.link_to(text, url)
             items.append(HTML.tag('li', c=[link]))
         return HTML.tag('ul', c=items)
 
+    # TODO: remove if no longer used
     def render_people_removable(self, customer, field):
         people = customer.people
         if not people:
@@ -431,7 +421,7 @@ class CustomerView(MasterView):
             return ""
         items = []
         for member in members:
-            text = six.text_type(member)
+            text = str(member)
             url = self.request.route_url('members.view', uuid=member.uuid)
             items.append(HTML.tag('li', tags.link_to(text, url)))
         return HTML.tag('ul', HTML.literal('').join(items))
@@ -448,7 +438,7 @@ class CustomerView(MasterView):
 
     def detach_person(self):
         customer = self.get_instance()
-        person = self.Session.query(model.Person).get(self.request.matchdict['person_uuid'])
+        person = self.Session.get(model.Person, self.request.matchdict['person_uuid'])
         if not person:
             return self.notfound()
 
@@ -587,7 +577,7 @@ class PendingCustomerView(MasterView):
         g.set_enum('status_code', self.enum.PENDING_CUSTOMER_STATUS)
         g.filters['status_code'].default_active = True
         g.filters['status_code'].default_verb = 'not_equal'
-        g.filters['status_code'].default_value = six.text_type(self.enum.PENDING_CUSTOMER_STATUS_RESOLVED)
+        g.filters['status_code'].default_value = str(self.enum.PENDING_CUSTOMER_STATUS_RESOLVED)
 
         g.set_sort_defaults('display_name')
         g.set_link('id')
@@ -622,7 +612,7 @@ class PendingCustomerView(MasterView):
         redirect = self.redirect(self.get_action_url('view', pending))
 
         uuid = self.request.POST['person_uuid']
-        person = self.Session.query(model.Person).get(uuid)
+        person = self.Session.get(model.Person, uuid)
         if not person:
             self.request.session.flash("Person not found!", 'error')
             return redirect
@@ -680,7 +670,7 @@ def customer_info(request):
     View which returns simple dictionary of info for a particular customer.
     """
     uuid = request.params.get('uuid')
-    customer = Session.query(model.Customer).get(uuid) if uuid else None
+    customer = Session.get(model.Customer, uuid) if uuid else None
     if not customer:
         return {}
     return {
