@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2020 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -28,5 +28,6 @@ from __future__ import unicode_literals, absolute_import
 
 
 def includeme(config):
+    config.include('tailbone.views.custorders.creating')
     config.include('tailbone.views.custorders.orders')
     config.include('tailbone.views.custorders.items')
