@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,11 +24,8 @@
 Customer order item views
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 
-import six
 from sqlalchemy import orm
 
 from rattail.db import model
@@ -156,7 +153,7 @@ class CustomerOrderItemView(MasterView):
     def render_person_text(self, item, field):
         person = item.order.person
         if person:
-            text = six.text_type(person)
+            text = str(person)
             return text
 
     def render_order_created(self, item, column):
@@ -165,14 +162,13 @@ class CustomerOrderItemView(MasterView):
 
     def render_status_code_column(self, item, field):
         text = self.enum.CUSTORDER_ITEM_STATUS.get(item.status_code,
-                                                   six.text_type(item.status_code))
+                                                   str(item.status_code))
         if item.status_text:
             return HTML.tag('span', title=item.status_text, c=[text])
         return text
 
     def configure_form(self, f):
         super(CustomerOrderItemView, self).configure_form(f)
-        use_buefy = self.get_use_buefy()
         item = f.model_instance
 
         # order
@@ -222,10 +218,7 @@ class CustomerOrderItemView(MasterView):
         f.set_renderer('status_code', self.render_status_code)
 
         # notes
-        if use_buefy:
-            f.set_renderer('notes', self.render_notes)
-        else:
-            f.remove('notes')
+        f.set_renderer('notes', self.render_notes)
 
     def highlight_pending_field(self, item, field, value=None):
         if value is None:
@@ -271,13 +264,12 @@ class CustomerOrderItemView(MasterView):
         return outer
 
     def render_status_code(self, item, field):
-        use_buefy = self.get_use_buefy()
         text = self.enum.CUSTORDER_ITEM_STATUS[item.status_code]
         if item.status_text:
             text = "{} ({})".format(text, item.status_text)
         items = [HTML.tag('span', c=[text])]
 
-        if use_buefy and self.has_perm('change_status'):
+        if self.has_perm('change_status'):
             button = HTML.tag('b-button', type='is-primary', c="Change Status",
                               style='margin-left: 1rem;',
                               icon_pack='fas', icon_left='edit',
@@ -416,7 +408,7 @@ class CustomerOrderItemView(MasterView):
         uuids = self.request.POST['uuids']
         if uuids:
             for uuid in uuids.split(','):
-                item = self.Session.query(model.CustomerOrderItem).get(uuid)
+                item = self.Session.get(model.CustomerOrderItem, uuid)
                 if item:
                     order_items.append(item)
 
@@ -484,14 +476,14 @@ class CustomerOrderItemView(MasterView):
         order = item.order
         if not order:
             return ""
-        text = six.text_type(order)
+        text = str(order)
         url = self.request.route_url('custorders.view', uuid=order.uuid)
         return tags.link_to(text, url)
 
     def render_person(self, item, field):
         person = item.order.person
         if person:
-            text = six.text_type(person)
+            text = str(person)
             url = self.request.route_url('people.view', uuid=person.uuid)
             return tags.link_to(text, url)
 
