@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,15 +24,10 @@
 Department Views
 """
 
-from __future__ import unicode_literals, absolute_import
-
-import six
-
 from rattail.db import model
 
 from webhelpers2.html import HTML
 
-from tailbone import grids
 from tailbone.views import MasterView
 
 
@@ -99,11 +94,10 @@ class DepartmentView(MasterView):
 
     def configure_form(self, f):
         super(DepartmentView, self).configure_form(f)
-        use_buefy = self.get_use_buefy()
 
         f.remove_field('subdepartments')
 
-        if not use_buefy or self.creating or self.editing:
+        if self.creating or self.editing:
             f.remove('employees')
         else:
             f.set_renderer('employees', self.render_employees)
@@ -137,33 +131,20 @@ class DepartmentView(MasterView):
 
     def template_kwargs_view(self, **kwargs):
         kwargs = super(DepartmentView, self).template_kwargs_view(**kwargs)
-        use_buefy = self.get_use_buefy()
         department = kwargs['instance']
-        department_employees = sorted(department.employees, key=six.text_type)
+        department_employees = sorted(department.employees, key=str)
 
-        if use_buefy:
-            employees = []
-            for employee in department_employees:
-                person = employee.person
-                employees.append({
-                    'uuid': employee.uuid,
-                    'first_name': person.first_name,
-                    'last_name': person.last_name,
-                    '_action_url_view': self.request.route_url('employees.view', uuid=employee.uuid),
-                    '_action_url_edit': self.request.route_url('employees.edit', uuid=employee.uuid),
-                })
-            kwargs['employees_data'] = employees
-
-        else: # not buefy
-            if department.employees:
-                actions = [
-                    grids.GridAction('view', icon='zoomin',
-                                     url=lambda r, i: self.request.route_url('employees.view', uuid=r.uuid))
-                ]
-                kwargs['employees'] = grids.Grid(None, department_employees, ['display_name'], request=self.request,
-                                                 model_class=model.Employee, main_actions=actions)
-            else:
-                kwargs['employees'] = None
+        employees = []
+        for employee in department_employees:
+            person = employee.person
+            employees.append({
+                'uuid': employee.uuid,
+                'first_name': person.first_name,
+                'last_name': person.last_name,
+                '_action_url_view': self.request.route_url('employees.view', uuid=employee.uuid),
+                '_action_url_edit': self.request.route_url('employees.edit', uuid=employee.uuid),
+            })
+        kwargs['employees_data'] = employees
 
         return kwargs
 
@@ -218,20 +199,14 @@ class DepartmentView(MasterView):
                            .distinct()\
                            .order_by(model.Department.name)
 
-        def configure(g):
-            g.configure(include=[
-                g.name,
-            ], readonly=True)
+        def normalize(dept):
+            return {
+                'uuid': dept.uuid,
+                'number': dept.number,
+                'name': dept.name,
+            }
 
-        def row_attrs(row, i):
-            return {'data-uuid': row.uuid}
-
-        grid = self.make_grid(data=data, sortable=False, filterable=False, pageable=False,
-                              configure=configure, width=None, checkboxes=True,
-                              row_attrs=row_attrs, main_actions=[], more_actions=[])
-        self.request.response.content_type = str('text/html')
-        self.request.response.text = grid.render_grid()
-        return self.request.response
+        return self.json_response([normalize(d) for d in data])
 
     @classmethod
     def defaults(cls, config):
