@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -64,5 +64,12 @@ class DepositLinkView(MasterView):
 DepositLinksView = DepositLinkView
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    DepositLinkView = kwargs.get('DepositLinkView', base['DepositLinkView'])
     DepositLinkView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
