@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,9 +24,6 @@
 Employee Views
 """
 
-from __future__ import unicode_literals, absolute_import
-
-import six
 import sqlalchemy as sa
 
 from rattail.db import model
@@ -84,7 +81,6 @@ class EmployeeView(MasterView):
     def configure_grid(self, g):
         super(EmployeeView, self).configure_grid(g)
         route_prefix = self.get_route_prefix()
-        use_buefy = self.get_use_buefy()
 
         # phone
         g.set_joiner('phone', lambda q: q.outerjoin(model.EmployeePhoneNumber, sa.and_(
@@ -127,10 +123,7 @@ class EmployeeView(MasterView):
             g.set_enum('status', self.enum.EMPLOYEE_STATUS)
             g.filters['status'].default_active = True
             g.filters['status'].default_verb = 'equal'
-            if use_buefy:
-                g.filters['status'].default_value = six.text_type(self.enum.EMPLOYEE_STATUS_CURRENT)
-            else:
-                g.filters['status'].default_value = self.enum.EMPLOYEE_STATUS_CURRENT
+            g.filters['status'].default_value = str(self.enum.EMPLOYEE_STATUS_CURRENT)
         else:
             g.remove('status')
             del g.filters['status']
@@ -202,7 +195,7 @@ class EmployeeView(MasterView):
         f.set_label('stores', "Stores") # TODO: should not be necessary
         if self.creating or self.editing:
             stores = self.get_possible_stores().all()
-            store_values = [(s.uuid, six.text_type(s)) for s in stores]
+            store_values = [(s.uuid, str(s)) for s in stores]
             f.set_node('stores', colander.SchemaNode(colander.Set()))
             f.set_widget('stores', dfwidget.SelectWidget(multiple=True,
                                                          size=len(stores),
@@ -214,7 +207,7 @@ class EmployeeView(MasterView):
         f.set_label('departments', "Departments") # TODO: should not be necessary
         if self.creating or self.editing:
             departments = self.get_possible_departments().all()
-            dept_values = [(d.uuid, six.text_type(d)) for d in departments]
+            dept_values = [(d.uuid, str(d)) for d in departments]
             f.set_node('departments', colander.SchemaNode(colander.Set()))
             f.set_widget('departments', dfwidget.SelectWidget(multiple=True,
                                                               size=len(departments),
@@ -256,7 +249,7 @@ class EmployeeView(MasterView):
                 employee._stores.append(model.EmployeeStore(store_uuid=uuid))
         for uuid in old_stores:
             if uuid not in new_stores:
-                store = self.Session.query(model.Store).get(uuid)
+                store = self.Session.get(model.Store, uuid)
                 employee.stores.remove(store)
 
     def update_departments(self, employee, data):
@@ -269,7 +262,7 @@ class EmployeeView(MasterView):
                 employee._departments.append(model.EmployeeDepartment(department_uuid=uuid))
         for uuid in old_depts:
             if uuid not in new_depts:
-                dept = self.Session.query(model.Department).get(uuid)
+                dept = self.Session.get(model.Department, uuid)
                 employee.departments.remove(dept)
 
     def get_possible_stores(self):
@@ -284,7 +277,7 @@ class EmployeeView(MasterView):
         person = employee.person if employee else None
         if not person:
             return ""
-        text = six.text_type(person)
+        text = str(person)
         url = self.request.route_url('people.view', uuid=person.uuid)
         return tags.link_to(text, url)
 
@@ -293,8 +286,8 @@ class EmployeeView(MasterView):
         if not stores:
             return ""
         items = []
-        for store in sorted(stores, key=six.text_type):
-            items.append(HTML.tag('li', c=six.text_type(store)))
+        for store in sorted(stores, key=str):
+            items.append(HTML.tag('li', c=str(store)))
         return HTML.tag('ul', c=items)
 
     def render_departments(self, employee, field):
@@ -302,8 +295,8 @@ class EmployeeView(MasterView):
         if not departments:
             return ""
         items = []
-        for department in sorted(departments, key=six.text_type):
-            items.append(HTML.tag('li', c=six.text_type(department)))
+        for department in sorted(departments, key=str):
+            items.append(HTML.tag('li', c=str(department)))
         return HTML.tag('ul', c=items)
 
     def touch_instance(self, employee):
