@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,12 +24,9 @@
 Views for 'ordering' (purchasing) batches
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import os
 import json
 
-import six
 import openpyxl
 from sqlalchemy import orm
 
@@ -244,7 +241,7 @@ class OrderingBatchView(PurchasingBatchView):
         assert not (batch.executed or batch.complete)
 
         uuid = data.get('row_uuid')
-        row = self.Session.query(self.model_row_class).get(uuid) if uuid else None
+        row = self.Session.get(self.model_row_class, uuid) if uuid else None
         if not row:
             return {'error': "Row not found"}
         if row.batch is not batch or row.removed:
@@ -313,9 +310,7 @@ class OrderingBatchView(PurchasingBatchView):
         if not order_date:
             order_date = localtime(self.rattail_config).date()
 
-        buefy_data = None
-        if self.get_use_buefy():
-            buefy_data = self.get_worksheet_buefy_data(departments)
+        buefy_data = self.get_worksheet_buefy_data(departments)
 
         return self.render_to_response('worksheet', {
             'batch': batch,
@@ -334,8 +329,8 @@ class OrderingBatchView(PurchasingBatchView):
 
     def get_worksheet_buefy_data(self, departments):
         data = {}
-        for department in six.itervalues(departments):
-            for subdepartment in six.itervalues(department._order_subdepartments):
+        for department in departments.values():
+            for subdepartment in department._order_subdepartments.values():
                 for i, cost in enumerate(subdepartment._order_costs, 1):
                     cases = int(cost._batchrow.cases_ordered or 0) if cost._batchrow else None
                     units = int(cost._batchrow.units_ordered or 0) if cost._batchrow else None
@@ -406,7 +401,7 @@ class OrderingBatchView(PurchasingBatchView):
             return {'error': "Invalid value for units ordered: {}".format(units_ordered)}
 
         uuid = data.get('product_uuid')
-        product = self.Session.query(model.Product).get(uuid) if uuid else None
+        product = self.Session.get(model.Product, uuid) if uuid else None
         if not product:
             return {'error': "Product not found"}
 
@@ -433,7 +428,7 @@ class OrderingBatchView(PurchasingBatchView):
                 self.handler.update_row_quantity(row, cases_ordered=cases_ordered,
                                                  units_ordered=units_ordered)
             except Exception as error:
-                return {'error': six.text_type(error)}
+                return {'error': str(error)}
 
         else: # empty order quantities
 
@@ -469,7 +464,7 @@ class OrderingBatchView(PurchasingBatchView):
         worksheet.append([])
         worksheet.append(['vendor_code', 'upc', 'brand_name', 'description', 'cases_ordered', 'units_ordered'])
         for row in batch.active_rows():
-            worksheet.append([row.vendor_code, six.text_type(row.upc), row.brand_name,
+            worksheet.append([row.vendor_code, str(row.upc), row.brand_name,
                               '{} {}'.format(row.description, row.size),
                               row.cases_ordered, row.units_ordered])
 
