@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,11 +24,8 @@
 Role Views
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import os
 
-import six
 from sqlalchemy import orm
 from openpyxl.styles import Font, PatternFill
 
@@ -172,7 +169,6 @@ class RoleView(PrincipalMasterView):
     def configure_form(self, f):
         super(RoleView, self).configure_form(f)
         role = f.model_instance
-        use_buefy = self.get_use_buefy()
         app = self.get_rattail_app()
         auth = app.get_auth_handler()
 
@@ -213,7 +209,7 @@ class RoleView(PrincipalMasterView):
         f.set_type('notes', 'text_wrapped')
 
         # users
-        if use_buefy and self.viewing:
+        if self.viewing:
             f.set_renderer('users', self.render_users)
         else:
             f.remove('users')
@@ -224,8 +220,7 @@ class RoleView(PrincipalMasterView):
                                                           permissions=self.tailbone_permissions))
         f.set_node('permissions', colander.Set())
         f.set_widget('permissions', PermissionsWidget(
-            permissions=self.tailbone_permissions,
-            use_buefy=use_buefy))
+            permissions=self.tailbone_permissions))
         if self.editing:
             granted = []
             for groupkey in self.tailbone_permissions:
@@ -298,8 +293,8 @@ class RoleView(PrincipalMasterView):
         # TODO: it seems a bit ugly, to "rebuild" permission groups like this,
         # but not sure if there's a better way?
         available = {}
-        for gkey, group in six.iteritems(permissions):
-            for pkey, perm in six.iteritems(group['perms']):
+        for gkey, group in permissions.items():
+            for pkey, perm in group['perms'].items():
                 if self.request.has_perm(pkey):
                     if gkey not in available:
                         available[gkey] = {
@@ -315,7 +310,7 @@ class RoleView(PrincipalMasterView):
             return "(not applicable)"
         if role.session_timeout is None:
             return ""
-        return six.text_type(role.session_timeout)
+        return str(role.session_timeout)
 
     def objectify(self, form, data=None):
         """
@@ -342,8 +337,8 @@ class RoleView(PrincipalMasterView):
         auth = app.get_auth_handler()
 
         available = self.tailbone_permissions
-        for gkey, group in six.iteritems(available):
-            for pkey, perm in six.iteritems(group['perms']):
+        for gkey, group in available.items():
+            for pkey, perm in group['perms'].items():
                 if pkey in permissions:
                     auth.grant_permission(role, pkey)
                 else:
@@ -367,23 +362,21 @@ class RoleView(PrincipalMasterView):
         kwargs['guest_role'] = guest_role(self.Session())
         kwargs['authenticated_role'] = authenticated_role(self.Session())
 
-        use_buefy = self.get_use_buefy()
-        if use_buefy:
-            role = kwargs['instance']
-            if role not in (kwargs['guest_role'], kwargs['authenticated_role']):
-                users_data = []
-                for user in role.users:
-                    users_data.append({
-                        'uuid': user.uuid,
-                        'full_name': user.display_name,
-                        'username': user.username,
-                        'active': "Yes" if user.active else "No",
-                        '_action_url_view': self.request.route_url('users.view',
-                                                                   uuid=user.uuid),
-                        '_action_url_edit': self.request.route_url('users.edit',
-                                                                   uuid=user.uuid),
-                    })
-                kwargs['users_data'] = users_data
+        role = kwargs['instance']
+        if role not in (kwargs['guest_role'], kwargs['authenticated_role']):
+            users_data = []
+            for user in role.users:
+                users_data.append({
+                    'uuid': user.uuid,
+                    'full_name': user.display_name,
+                    'username': user.username,
+                    'active': "Yes" if user.active else "No",
+                    '_action_url_view': self.request.route_url('users.view',
+                                                               uuid=user.uuid),
+                    '_action_url_edit': self.request.route_url('users.edit',
+                                                               uuid=user.uuid),
+                })
+            kwargs['users_data'] = users_data
 
         return kwargs
 
