@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,11 +24,8 @@
 Base views for time sheets
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 
-import six
 import sqlalchemy as sa
 
 from rattail import enum
@@ -105,10 +102,10 @@ class TimeSheetView(View):
         if store_key in self.request.session or department_key in self.request.session:
             store_uuid = self.request.session.get(store_key)
             if store_uuid:
-                store = Session.query(model.Store).get(store_uuid) if store_uuid else None
+                store = Session.get(model.Store, store_uuid) if store_uuid else None
             department_uuid = self.request.session.get(department_key)
             if department_uuid:
-                department = Session.query(model.Department).get(department_uuid)
+                department = Session.get(model.Department, department_uuid)
         else: # no store/department in session
             if self.default_filter_store:
                 store = self.rattail_config.get('rattail', 'store')
@@ -151,7 +148,7 @@ class TimeSheetView(View):
         employee_key = 'timesheet.{}.employee'.format(self.key)
         if employee_key in self.request.session:
             employee_uuid = self.request.session[employee_key]
-            employee = Session.query(model.Employee).get(employee_uuid) if employee_uuid else None
+            employee = Session.get(model.Employee, employee_uuid) if employee_uuid else None
         if not employee:
             employee = self.request.user.employee
 
@@ -238,7 +235,7 @@ class TimeSheetView(View):
         form = forms.Form(schema=EmployeeShiftFilter(), request=self.request)
 
         if self.request.has_perm('{}.viewall'.format(permission_prefix)):
-            employee_display = six.text_type(context['employee'] or '')
+            employee_display = str(context['employee'] or '')
             employees_url = self.request.route_url('employees.autocomplete')
             form.set_widget('employee', forms.widgets.JQueryAutocompleteWidget(
                 field_display=employee_display, service_url=employees_url))
@@ -470,7 +467,7 @@ class TimeSheetView(View):
                     if hours_style == 'pretty':
                         display = pretty_hours(hours)
                     else: # decimal
-                        display = six.text_type(hours_as_decimal(hours))
+                        display = str(hours_as_decimal(hours))
                     if empday['hours_incomplete']:
                         display = '{} ?'.format(display)
                     empday['{}_hours_display'.format(shift_type)] = display
@@ -481,7 +478,7 @@ class TimeSheetView(View):
                 if hours_style == 'pretty':
                     display = pretty_hours(hours)
                 else: # decimal
-                    display = six.text_type(hours_as_decimal(hours))
+                    display = str(hours_as_decimal(hours))
                 if hours_incomplete:
                     display = '{} ?'.format(display)
                 setattr(employee, '{}_hours_display'.format(shift_type), display)
