@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -159,6 +159,14 @@ class TempmonClientView(MasterView):
         # archived
         f.set_helptext('archived', tempmon.Client.archived.__doc__)
 
+    def template_kwargs_view(self, **kwargs):
+        kwargs = super(TempmonClientView, self).template_kwargs_view(**kwargs)
+        client = kwargs['instance']
+
+        kwargs['probes_data'] = self.normalize_probes(client.probes)
+
+        return kwargs
+
     def objectify(self, form, data=None):
 
         # this is a hack to prevent updates to the 'enabled' timestamp, when
