@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Common stuff for tempmon views
 """
 
-from __future__ import unicode_literals, absolute_import
-
 from webhelpers2.html import HTML
 
 from tailbone import views, grids
@@ -42,6 +40,28 @@ class MasterView(views.MasterView):
         from rattail_tempmon.db import Session
         return Session()
 
+    def normalize_probes(self, probes):
+        data = []
+        for probe in probes:
+            view_url = self.request.route_url('tempmon.probes.view', uuid=probe.uuid)
+            edit_url = self.request.route_url('tempmon.probes.edit', uuid=probe.uuid)
+            data.append({
+                'uuid': probe.uuid,
+                'url': view_url,
+                '_action_url_view': view_url,
+                '_action_url_edit': edit_url,
+                'description': probe.description,
+                'critical_temp_min': probe.critical_temp_min,
+                'good_temp_min': probe.good_temp_min,
+                'good_temp_max': probe.good_temp_max,
+                'critical_temp_max': probe.critical_temp_max,
+                'status': self.enum.TEMPMON_PROBE_STATUS[probe.status],
+                'enabled': "Yes" if probe.enabled else "No",
+            })
+        app = self.get_rattail_app()
+        data = app.json_friendly(data)
+        return data
+
     def render_probes(self, obj, field):
         """
         This method is used by Appliance and Client views.
@@ -50,17 +70,15 @@ class MasterView(views.MasterView):
             return ""
 
         route_prefix = self.get_route_prefix()
-        view_url = lambda p, i: self.request.route_url('tempmon.probes.view', uuid=p.uuid)
-        actions = [
-            grids.GridAction('view', icon='zoomin', url=view_url),
-        ]
-        if self.request.has_perm('tempmon.probes.edit'):
-            url = lambda p, i: self.request.route_url('tempmon.probes.edit', uuid=p.uuid)
-            actions.append(grids.GridAction('edit', icon='pencil', url=url))
 
-        g = grids.Grid(
+        actions = [self.make_grid_action_view()]
+        if self.request.has_perm('tempmon.probes.edit'):
+            actions.append(self.make_grid_action_edit())
+
+        factory = self.get_grid_factory()
+        g = factory(
             key='{}.probes'.format(route_prefix),
-            data=obj.probes,
+            data=[],
             columns=[
                 'description',
                 'critical_temp_min',
@@ -76,10 +94,8 @@ class MasterView(views.MasterView):
                 'good_temp_max': "Good Max",
                 'critical_temp_max': "Crit. Max",
             },
-            url=lambda p: self.request.route_url('tempmon.probes.view', uuid=p.uuid),
             linked_columns=['description'],
             main_actions=actions,
         )
-        g.set_enum('status', self.enum.TEMPMON_PROBE_STATUS)
-        g.set_type('enabled', 'boolean')
-        return HTML.literal(g.render_grid())
+        return HTML.literal(
+            g.render_buefy_table_element(data_prop='probesData'))
