@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,12 +24,8 @@
 Views for tempmon probes
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 
-import six
-
 from rattail.time import make_utc, localtime
 from rattail_tempmon.db import model as tempmon
 
@@ -206,7 +202,7 @@ class TempmonProbeView(MasterView):
         client = probe.client
         if not client:
             return ""
-        text = six.text_type(client)
+        text = str(client)
         url = self.request.route_url('tempmon.clients.view', uuid=client.uuid)
         return tags.link_to(text, url)
 
@@ -214,7 +210,7 @@ class TempmonProbeView(MasterView):
         appliance = probe.appliance
         if not appliance:
             return ""
-        text = six.text_type(appliance)
+        text = str(appliance)
         url = self.request.route_url('tempmon.appliances.view', uuid=appliance.uuid)
         return tags.link_to(text, url)
 
@@ -255,7 +251,6 @@ class TempmonProbeView(MasterView):
 
     def graph(self):
         probe = self.get_instance()
-        use_buefy = self.get_use_buefy()
 
         key = 'tempmon.probe.{}.graph_time_range'.format(probe.uuid)
         selected = self.request.params.get('time-range')
@@ -270,16 +265,13 @@ class TempmonProbeView(MasterView):
             tags.Option("Last Week", 'last week'),
         ])
 
-        if use_buefy:
-            time_range = HTML.tag('b-select', c=[range_options.render()],
-                                  **{'v-model': 'currentTimeRange',
-                                     '@input': 'timeRangeChanged'})
-        else:
-            time_range = tags.select('time-range', selected, range_options)
+        time_range = HTML.tag('b-select', c=[range_options.render()],
+                              **{'v-model': 'currentTimeRange',
+                                 '@input': 'timeRangeChanged'})
 
         context = {
             'probe': probe,
-            'parent_title': six.text_type(probe),
+            'parent_title': str(probe),
             'parent_url': self.get_action_url('view', probe),
             'time_range': time_range,
             'current_time_range': selected,
