@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -39,5 +39,12 @@ class TransactionView(base.TransactionView):
     model_row_class = trainwreck.TransactionItem
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    TransactionView = kwargs.get('TransactionView', base['TransactionView'])
     TransactionView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
