@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,15 +24,12 @@
 Views for app upgrades
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import json
 import os
 import re
 import logging
 import warnings
 
-import six
 import sqlalchemy as sa
 
 from rattail.core import Object
@@ -63,6 +60,7 @@ class UpgradeView(MasterView):
     executable = True
     execute_progress_template = '/upgrade.mako'
     execute_progress_initial_msg = "Upgrading"
+    execute_can_cancel = False
 
     labels = {
         'executed_by': "Executed by",
@@ -251,25 +249,24 @@ class UpgradeView(MasterView):
         code = getattr(upgrade, field)
         text = self.enum.UPGRADE_STATUS[code]
 
-        if self.get_use_buefy():
-            if code == self.enum.UPGRADE_STATUS_EXECUTING:
+        if code == self.enum.UPGRADE_STATUS_EXECUTING:
 
-                text = HTML.tag('span', c=[text])
+            text = HTML.tag('span', c=[text])
 
-                button = HTML.tag('b-button',
-                                  type='is-warning',
-                                  icon_pack='fas',
-                                  icon_left='sad-tear',
-                                  c=['{{ declareFailureSubmitting ? "Working, please wait..." : "Declare Failure" }}'],
-                                  **{':disabled': 'declareFailureSubmitting',
-                                     '@click': 'declareFailureClick'})
+            button = HTML.tag('b-button',
+                              type='is-warning',
+                              icon_pack='fas',
+                              icon_left='sad-tear',
+                              c=['{{ declareFailureSubmitting ? "Working, please wait..." : "Declare Failure" }}'],
+                              **{':disabled': 'declareFailureSubmitting',
+                                 '@click': 'declareFailureClick'})
 
-                return HTML.tag('div', class_='level', c=[
-                    HTML.tag('div', class_='level-left', c=[
-                        HTML.tag('div', class_='level-item', c=[text]),
-                        HTML.tag('div', class_='level-item', c=[button]),
-                    ]),
-                ])
+            return HTML.tag('div', class_='level', c=[
+                HTML.tag('div', class_='level-left', c=[
+                    HTML.tag('div', class_='level-item', c=[text]),
+                    HTML.tag('div', class_='level-item', c=[button]),
+                ]),
+            ])
 
         # just show status per normal
         return text
@@ -302,14 +299,12 @@ class UpgradeView(MasterView):
         return filename
 
     def render_package_diff(self, upgrade, fieldname):
-        use_buefy = self.get_use_buefy()
         try:
             before = self.parse_requirements(upgrade, 'before')
             after = self.parse_requirements(upgrade, 'after')
 
             kwargs = {}
-            if use_buefy:
-                kwargs['extra_row_attrs'] = self.get_extra_diff_row_attrs
+            kwargs['extra_row_attrs'] = self.get_extra_diff_row_attrs
             diff = self.make_diff(before, after,
                                   columns=["package", "old version", "new version"],
                                   render_field=self.render_diff_field,
@@ -317,24 +312,16 @@ class UpgradeView(MasterView):
                                   **kwargs)
 
             kwargs = {}
-            if use_buefy:
-                kwargs['@click.prevent'] = "showingPackages = 'all'"
-                kwargs[':style'] = "{'font-weight': showingPackages == 'all' ? 'bold' : null}"
-            else:
-                kwargs['class_'] = 'all'
+            kwargs['@click.prevent'] = "showingPackages = 'all'"
+            kwargs[':style'] = "{'font-weight': showingPackages == 'all' ? 'bold' : null}"
             all_link = tags.link_to("all", '#', **kwargs)
 
             kwargs = {}
-            if use_buefy:
-                kwargs['@click.prevent'] = "showingPackages = 'diffs'"
-                kwargs[':style'] = "{'font-weight': showingPackages == 'diffs' ? 'bold' : null}"
-            else:
-                kwargs['class_'] = 'diffs'
+            kwargs['@click.prevent'] = "showingPackages = 'diffs'"
+            kwargs[':style'] = "{'font-weight': showingPackages == 'diffs' ? 'bold' : null}"
             diffs_link = tags.link_to("diffs only", '#', **kwargs)
 
             kwargs = {}
-            if not use_buefy:
-                kwargs['class_'] = 'showing'
             showing = HTML.tag('div', c=["showing: "
                                          + all_link
                                          + " / "
