@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Views pertaining to vendors
 """
 
-from __future__ import unicode_literals, absolute_import
-
 from .core import VendorView
 
 
@@ -36,3 +34,4 @@ def defaults(config, **kwargs):
 
 def includeme(config):
     config.include('tailbone.views.vendors.core')
+    config.include('tailbone.views.vendors.samplefiles')
